#include <stdint.h>
#include <avr/io.h>
#include <util/delay.h>

#define RC5_DDR DDRD
#define RC5_PORT PORTD
#define RC5_BIT PD0

typedef union
{
  uint16_t code;
  struct
  {
    uint8_t unused: 2; 		// Bits 1..0 	not used
    uint8_t command: 6; 	// Bits 7..2	command bits
    uint8_t address: 5; 	// Bits 12..8	address bits
    uint8_t toggle: 1; 		// Bits 13 		toggle bit
    uint8_t start: 2; 		// Bits 15..14 	start bits
  };
} RC5_DATA;

#define RC5_BITS 14 		// Anzahl der Bits
#define	RC5_CYCLES 32		// Halbbit wird 32 mal an- und ausgeschaltet bei 36kHz Modulation {1,778ms/(1/36kHz)=64}
#define RC5_BIT_TIME 889 	// Signaldauer fr 1 Halbbit in s (32/36000) bei 36kHz Modulation

// Macros
#define RC5_INIT_PORT() (RC5_DDR |=(1<< RC5_BIT))
#define RC5_SET() (RC5_PORT |= (1<<RC5_BIT))
#define RC5_CLR() (RC5_PORT &= ~(1<<RC5_BIT))

void rc5_send(RC5_DATA * rc5);
void delay_us(uint16_t time);


